@@ -1,6 +1,4 @@
 /*
- * ipconfig/bootp_proto.c
- *
  * BOOTP packet protocol handling.
  */
 #include <sys/types.h>
@@ -74,6 +72,7 @@ int bootp_parse(struct netdev *dev, struct bootp_hdr *hdr,
 	dev->hostname[0]	= '\0';
 	dev->nisdomainname[0]	= '\0';
 	dev->bootpath[0]	= '\0';
+	memcpy(&dev->filename, &hdr->boot_file, FNLEN);
 
 	if (extlen >= 4 && exts[0] == 99 && exts[1] == 130 &&
 	    exts[2] == 83 && exts[3] == 99) {
@@ -136,7 +135,7 @@ int bootp_parse(struct netdev *dev, struct bootp_hdr *hdr,
 				memcpy(&dev->nisdomainname, ext, len);
 				dev->nisdomainname[len] = '\0';
 				break;
-			case 54: 	/* server identifier */
+			case 54:	/* server identifier */
 				if (len == 4 && !dev->ip_server)
 					memcpy(&dev->ip_server, ext, 4);
 				break;
@@ -154,6 +153,10 @@ int bootp_parse(struct netdev *dev, struct bootp_hdr *hdr,
 
 /*
  * Receive a bootp reply and parse packet
+ * Returns:
+ *-1 = Error in packet_recv, try again later
+ * 0 = Unexpected packet, discarded
+ * 1 = Correctly received and parsed packet
  */
 int bootp_recv_reply(struct netdev *dev)
 {
@@ -168,7 +171,7 @@ int bootp_recv_reply(struct netdev *dev)
 
 	ret = packet_recv(iov, 3);
 	if (ret <= 0)
-		return ret;
+		return -1;
 
 	if (ret < sizeof(struct bootp_hdr) ||
 	    bootp.op != BOOTP_REPLY ||	/* RFC951 7.5 */
